import { EntityRepository, Repository } from "typeorm";
import { UpdateAgeVerificationCmsDto } from "./dto/update-age-verification-cms.dto";
import { AgeVerificationCms } from "./entities/age-verification-cms.entity";

@EntityRepository(AgeVerificationCms)
export class AgeVerificationCmsRepository extends Repository<AgeVerificationCms> {

    async createEntity(dto: UpdateAgeVerificationCmsDto): Promise<AgeVerificationCms | Error> {
        try {
            const entity = this.create({
                backgroundImage: dto.backgroundImage,
                logo: dto.logo,
                title: dto.title,
                subTitle: dto.subTitle,
                buttonOneText: dto.buttonOneText,
                buttonTwoText: dto.buttonTwoText,
                isNoButtonShow: dto.isNoButtonShow.toString() == 'true' ? true : false,
                isCheckboxShow: dto.isCheckboxShow.toString() == 'true' ? true : false,
                checkboxStatus: dto.checkboxStatus.toString() == 'true' ? true : false
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async updateEntity(dto: UpdateAgeVerificationCmsDto, id: string): Promise<AgeVerificationCms | Error> {
        try {
            await this.update(id, {
                backgroundImage: dto.backgroundImage,
                logo: dto.logo,
                title: dto.title,
                subTitle: dto.subTitle,
                buttonOneText: dto.buttonOneText,
                buttonTwoText: dto.buttonTwoText,
                isNoButtonShow: dto.isNoButtonShow.toString() == 'true' ? true : false,
                isCheckboxShow: dto.isCheckboxShow.toString() == 'true' ? true : false,
                checkboxStatus: dto.checkboxStatus.toString() == 'true' ? true : false
            });
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async findAll(): Promise<AgeVerificationCms[] | Error> {
        try {
            return await this.find({
                where: {
                    isDeleted: false
                }
            });
        } catch (e) {
            return e;
        }
    }
}