import {
    Body,
    Controller,
    Get,
    HttpCode,
    HttpStatus,
    Post,
    UploadedFiles,
    UseGuards,
    UseInterceptors
} from "@nestjs/common";
import { AdminAuthGuard } from "src/core/guards/admin-auth.guard";
import { Constants } from "src/utils/constants";
import { DealsPopupCmsService } from "./deals-popup-cms.service";
import { UpdateDealsPopupCmsDto } from "./dto/update-about-page-cms.dto";
import { FileFieldsInterceptor } from "@nestjs/platform-express";
import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";

@Controller({ path: "deals-popup-cms", version: Constants.API_VERSION_1 })

export class DealsPopupCmsController {
    constructor(private readonly service: DealsPopupCmsService) {
    }

    @Post()
    @HttpCode(HttpStatus.OK)
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor(
      [
          { name: "bannerOneImage", maxCount: 1 },
          { name: "bannerTwoImage", maxCount: 1 }
      ]
    ))
    updateOrCreateData(
      @Body() dto: UpdateDealsPopupCmsDto,
      @UploadedFiles() files: {
          bannerOneImage: UploadedMulterFileI,
          bannerTwoImage: UploadedMulterFileI
      }
    ) {
        return this.service.updateOrCreateData(dto, files);
    }

    @Get()
    // @UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }
}
