import { HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectRepository } from "@nestjs/typeorm";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { DealsPopupCmsRepository } from "./deals-popup-cms.repository";
import { UpdateDealsPopupCmsDto } from "./dto/update-about-page-cms.dto";
import { DealsPopupCms } from "./entities/deals-popup-cms.entity";
import { DoSpacesService } from "src/modules/SpacesModule/SpacesService/doSpacesService";
import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";

@Injectable()
export class DealsPopupCmsService {
    constructor(
      @InjectRepository(DealsPopupCmsRepository)
      private readonly repository: DealsPopupCmsRepository,
      private readonly doSpaceService: DoSpacesService
    ) {
    }

    async updateOrCreateData(
      dto: UpdateDealsPopupCmsDto,
      files: {
          bannerOneImage: UploadedMulterFileI,
          bannerTwoImage: UploadedMulterFileI
      }
    ): Promise<DealsPopupCms | Error> {
        if (files && files.bannerOneImage) {
            const bannerOneImage: any = await this.doSpaceService.uploadFile(files.bannerOneImage[0], "DealsPopupCMS/");
            dto.bannerOneImage = bannerOneImage;
        }

        if (files && files.bannerTwoImage) {
            const bannerTwoImage: any = await this.doSpaceService.uploadFile(files.bannerTwoImage[0], "DealsPopupCMS/");
            dto.bannerTwoImage = bannerTwoImage;
        }

        const isExists = await this.repository.find({ isDeleted: false });
        if (Object.keys(isExists).length === 0) {
            const data = await this.repository.createEntity(dto);
            if (!data) {
                throw new HttpException(
                  Constants.NOT_FOUND,
                  HttpStatus.NOT_FOUND
                );
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            let id = isExists[0].id;
            const data = await this.repository.updateEntity(dto, id);
            if (!data) {
                throw new HttpException(
                  Constants.UPDATE_FAILED,
                  HttpStatus.BAD_REQUEST
                );
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<DealsPopupCms[] | Error> {
        const data = await this.repository.findAll();
        if (!data) {
            throw new HttpException(
              Constants.NOT_FOUND,
              HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}