import { HttpException, HttpStatus, Injectable, NotFoundException } from "@nestjs/common";
import { InjectRepository } from "@nestjs/typeorm";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { HomePageSectionThreeCmsRepository } from "./home-page-section-three-cms.repository";
import { UpdateHomePageSectionThreeCmsDto } from "./dto/update-home-page-section-three-cms.dto";
import { HomePageSectionThreeCms } from "./entities/home-page-section-three-cms.entity";
import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { DoSpacesService } from "src/modules/SpacesModule/SpacesService/doSpacesService";

@Injectable()
export class HomePageSectionThreeCmsService {
    constructor(
      @InjectRepository(HomePageSectionThreeCmsRepository)
      private readonly repository: HomePageSectionThreeCmsRepository,
      private readonly doSpaceService: DoSpacesService
    ) {
    }

    async updateOrCreateData(
      dto: UpdateHomePageSectionThreeCmsDto,
      files: {
          image: UploadedMulterFileI
      }
    ): Promise<HomePageSectionThreeCms | Error> {
        if (files && files.image) {
            const image: any = await this.doSpaceService.uploadFile(files.image[0], "HeaderCMS/");
            dto.image = image;
        }
        const isExists = await this.repository.find({ isDeleted: false });
        // const defaultCheck: any = dto.isDefault;
        // dto.isDefault = defaultCheck === "true" ? true : false;
        // if (dto.isDefault) {
        //     // Retrieve all entities
        //     const entities = await this.repository.find();

        //     // Update the isDefault property for each entity
        //     for (const entity of entities) {
        //         const updateData = await this.repository.update(entity.id, { isDefault: false });
        //     }
        // }
        if (Object.keys(isExists).length === 0) {
            const data = await this.repository.createEntity(dto);
            if (!data) {
                throw new HttpException(
                  Constants.NOT_FOUND,
                  HttpStatus.NOT_FOUND
                );
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            let id = isExists[0].id;
            const data = await this.repository.updateEntity(dto, id);
            if (!data) {
                throw new HttpException(
                  Constants.UPDATE_FAILED,
                  HttpStatus.BAD_REQUEST
                );
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<HomePageSectionThreeCms[] | Error> {
        const data = await this.repository.find({
            // stateCode: stateCode,
            isDeleted: false
        });
        if (!data) {
            throw new NotFoundException(Constants.NOT_FOUND);
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}