import { EntityRepository, getConnection, Repository } from "typeorm";
import { CreateDeliveryPagesDto } from "./dto/create-delivery-pages.dto";
import { UpdateDeliveryPagesDto } from "./dto/update-delivery-pages.dto";
import { DeliveryPages } from "./entities/delivery-pages.entity";

@EntityRepository(DeliveryPages)
export class DeliveryPagesRepository extends Repository<DeliveryPages> {
    async createEntity(dto: CreateDeliveryPagesDto): Promise<DeliveryPages | Error> {
        try {
            const entity = this.create({...dto});
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<DeliveryPages | Error> {
        try {
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdateDeliveryPagesDto): Promise<DeliveryPages | Error> {
        try {
            await this.update(id, {...dto});
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<DeliveryPages[] | Error> {
        try {
            return await this.find({
                where: { ...query, isDeleted: false }
            });
        } catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
              .createQueryBuilder()
              .update(DeliveryPages)
              .set({ isDeleted: true })
              .where("id = :id", { id: id })
              .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        } catch (e) {
            return e;
        }
    }
}