import { HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { CreateAlpineiqDto } from "./dto/create-alpineiq.dto";
import { UpdateAlpineiqDto } from "./dto/update-alpineiq.dto";
import axios from "axios";
import { Constants } from "src/utils/constants";
import { InjectRepository } from "@nestjs/typeorm";
import {
    RetailerServiceRepository
} from "../dutchie-plus/custom-services/retailer-service/retailer-service.repository";

@Injectable()
export class AlpineiqService {
    constructor(
      @InjectRepository(RetailerServiceRepository)
      private readonly retailerServiceRepository: RetailerServiceRepository
    ) {
    }

    async personaCreateNewContact(dto: CreateAlpineiqDto) {
        const retailerService = await this.retailerServiceRepository.findOne({
            where: {
                retailerId: dto.retailerId,
                isDeleted: false
            }
        });
        if (!retailerService) {
            throw new HttpException(
              Constants.NOT_FOUND,
              HttpStatus.NOT_FOUND
            );
        }
        const apiUrl = "https://lab.alpineiq.com/api/v1.1/loyaltyContact/:uid?optionalstore=true";
        const data = {
            firstName: dto.firstName,
            lastName: dto.lastName,
            mobilePhone: dto.mobilePhone,
            email: dto.email,
            disableSMS: false,
            smsoptin: true
        };

        const config = {
            headers: {
                "x-apikey": retailerService.alpineIqApiKey,
                "Content-Type": "application/json"
            }
        };

        const uid = retailerService.alpineIqUID;

        try {
            const response = await axios.post(apiUrl.replace(":uid", uid), data, config);
            if (response.status === 200) {
                return response.data;
            }
        } catch (e) {
            // if (e.response.status === 403) {
            //     throw new HttpException(
            //       "You are not eligible for this store!",
            //       HttpStatus.FORBIDDEN
            //     );
            // }
            throw new HttpException(
              "You are not eligible for this store!",
              HttpStatus.FORBIDDEN
            );
        }
    }

    async personasFindAll(retailerId: any) {
        const retailerService = await this.retailerServiceRepository.findOne({
            where: {
                retailerId: retailerId,
                isDeleted: false
            }
        });
        if (!retailerService) {
            throw new HttpException(
              Constants.NOT_FOUND,
              HttpStatus.NOT_FOUND
            );
        }
        const apiUrl = "https://lab.alpineiq.com/api/v1.1/piis/:uid";
        const config = {
            headers: {
                "x-apikey": retailerService.alpineIqApiKey,
                "Content-Type": "application/json"
            },
            params: {
                sort: "inserted",
                dir: "desc"
            }
        };

        const uid = retailerService.alpineIqUID;

        try {
            const response = await axios.get(apiUrl.replace(":uid", uid), config);
            if (response.status === 200) {
                return response.data;
            }
        } catch (e) {
            console.log(e);
            return e;
        }
    }

    async personaByContactID(retailerId: string, contactID: string) {
        const retailerService = await this.retailerServiceRepository.findOne({
            where: {
                retailerId: retailerId,
                isDeleted: false
            }
        });
        if (!retailerService) {
            throw new HttpException(
              Constants.NOT_FOUND,
              HttpStatus.NOT_FOUND
            );
        }
        const apiUrl = `https://lab.alpineiq.com/api/v1.1/piis/:uid/${contactID}`;

        const config = {
            headers: {
                "x-apikey": retailerService.alpineIqApiKey,
                "Content-Type": "application/json"
            }
        };
        const uid = retailerService.alpineIqUID;

        try {
            const response = await axios.get(apiUrl.replace(":uid", uid), config);
            if (response.status === 200) {
                return response.data;
            }
        } catch (e) {
            console.log(e);
            return e;
        }
    }


    async getLoyaltyStatus(pii: string) {
        const apiUrl = `https://lab.alpineiq.com/api/v2/loyalty/lookup/:pii`;
        const config = {
            headers: {
                "x-apikey": process.env.ALPINEIQ_API_KEY,
                "Content-Type": "application/json"
            }
        };

        try {
            const response = await axios.get(apiUrl.replace(":pii", pii), config);
            if (response.status === 200) {
                return response.data;
            }
        } catch (e) {
            console.log(e);
            return e;
        }
    }

    update(id: number, updateAlpineiqDto: UpdateAlpineiqDto) {
        return `This action updates a #${id} alpineiq`;
    }

    remove(id: number) {
        return `This action removes a #${id} alpineiq`;
    }
}
