import {
    Body,
    Controller,
    Delete,
    Get,
    Param,
    Patch,
    Post,
    UploadedFiles,
    UseGuards,
    UseInterceptors
} from "@nestjs/common";
import { AdminAuthGuard } from "src/core/guards/admin-auth.guard";
import { Constants } from "src/utils/constants";
import { FileFieldsInterceptor } from "@nestjs/platform-express";
import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { ArticleCategoryService } from "./article-category.service";
import { UpdateArticleCategoryDto } from "./dto/update-article-category.dto";
import { BaseArticleCategoryDto } from "./dto/base-article-category.dto";

@Controller({ path: "article-category", version: Constants.API_VERSION_1 })

export class ArticleCategoryController {
    constructor(private readonly service: ArticleCategoryService) {
    }

    @Post()
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor(
      [
          { name: "imageOne", maxCount: 1 },
          { name: "imageTwo", maxCount: 1 }
      ]
    ))
    create(@Body() dto: BaseArticleCategoryDto,
           @UploadedFiles() files: {
               imageOne: UploadedMulterFileI,
               imageTwo: UploadedMulterFileI,
           }) {
        return this.service.create(dto, files);
    }

    @Get()
    // @UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }

    @Get(":id")
    @UseGuards(AdminAuthGuard)
    findOne(@Param("id") id: string) {
        return this.service.findOne(id);
    }

    @Patch("/:id")
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor(
      [
          { name: "imageOne", maxCount: 1 },
          { name: "imageTwo", maxCount: 1 }
      ]
    ))
    update(
      @Param("id") id: string,
      @Body() dto: UpdateArticleCategoryDto,
      @UploadedFiles() files: {
          imageOne: UploadedMulterFileI,
          imageTwo: UploadedMulterFileI,
      }) {
        return this.service.update(id, dto, files);
    }

    @Delete(":id")
    @UseGuards(AdminAuthGuard)
    async remove(@Param("id") id: string) {
        return await this.service.remove(id);
    }
}
