import { EntityRepository, Repository } from "typeorm";
import { UpdatePrivacyPolicyPageUiDto } from "./dto/update-privacy-policy-page-ui.dto";
import { PrivacyPolicyPageUI } from "./entities/privacy-policy-page-ui.entity";

@EntityRepository(PrivacyPolicyPageUI)
export class PrivacyPolicyPageUiRepository extends Repository<PrivacyPolicyPageUI> {

    async createEntity(dto: UpdatePrivacyPolicyPageUiDto): Promise<PrivacyPolicyPageUI | Error> {
        try {
            const entity = this.create({
                titleFontColor: dto.titleFontColor,
                descriptionFontColor: dto.descriptionFontColor,
                pageBackgroundColor: dto.pageBackgroundColor,
                pageBreadcrumbFontColor: dto.pageBreadcrumbFontColor
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async updateEntity(dto: UpdatePrivacyPolicyPageUiDto, id: string): Promise<PrivacyPolicyPageUI | Error> {
        try {
            await this.update(id, {
                titleFontColor: dto.titleFontColor,
                descriptionFontColor: dto.descriptionFontColor,
                pageBackgroundColor: dto.pageBackgroundColor,
                pageBreadcrumbFontColor: dto.pageBreadcrumbFontColor
            });
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async findAll(): Promise<PrivacyPolicyPageUI[] | Error> {
        try {
            return await this.find({
                where: {
                    isDeleted: false
                }
            });
        } catch (e) {
            return e;
        }
    }
}