import { HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectRepository } from "@nestjs/typeorm";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { DoSpacesService } from "src/modules/SpacesModule/SpacesService/doSpacesService";
import { PrivacyPolicyPageUiRepository } from "./privacy-policy-page-ui.repository";
import { UpdatePrivacyPolicyPageUiDto } from "./dto/update-privacy-policy-page-ui.dto";
import { PrivacyPolicyPageUI } from "./entities/privacy-policy-page-ui.entity";

@Injectable()
export class PrivacyPolicyPageUiService {
    constructor(
      @InjectRepository(PrivacyPolicyPageUiRepository)
      private readonly repository: PrivacyPolicyPageUiRepository,
      private readonly doSpaceService: DoSpacesService
    ) {
    }

    async updateOrCreateData(
      dto: UpdatePrivacyPolicyPageUiDto
    ): Promise<PrivacyPolicyPageUI | Error> {
        const isExists = await this.repository.find({ isDeleted: false });
        if (Object.keys(isExists).length === 0) {
            const data = await this.repository.createEntity(dto);
            if (!data) {
                throw new HttpException(
                  Constants.NOT_FOUND,
                  HttpStatus.NOT_FOUND
                );
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            let id = isExists[0].id;
            const data = await this.repository.updateEntity(dto, id);
            if (!data) {
                throw new HttpException(
                  Constants.UPDATE_FAILED,
                  HttpStatus.BAD_REQUEST
                );
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<PrivacyPolicyPageUI[] | Error> {
        const data = await this.repository.findAll();
        if (!data) {
            throw new HttpException(
              Constants.NOT_FOUND,
              HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}