import { EntityRepository, getConnection, Repository } from "typeorm";
import { RetailerServiceIHeartJane } from "./entities/retailer-service-iheartjane.entity";

@EntityRepository(RetailerServiceIHeartJane)
export class RetailerServiceIHeartJaneRepository extends Repository<RetailerServiceIHeartJane> {
    async createEntity(dto: any): Promise<RetailerServiceIHeartJane | Error> {
        try {
            const {
                retailerId,
                retailerName,
                full_address,
                delivery,
                description,
                google_map_url,
                hours,
                lat,
                long,
                medical,
                phone,
                photo,
                pickup,
                recreational,
                time_zone_identifier,
                url_slug,
                accessCount,
                retailerImage,
                featuredImage,
                alpineIqApiKey,
                alpineIqUID,
                about,
                todaysSpecial,
                email,
                jarsRewards,
                referAFriend,
                pageTitle,
                schema,
                canonical
            } = dto;
            const entity = this.create({
                retailerId,
                retailerName,
                full_address,
                delivery,
                description,
                google_map_url,
                hours,
                lat,
                long,
                medical,
                phone,
                photo,
                pickup,
                recreational,
                time_zone_identifier,
                url_slug,
                accessCount,
                retailerImage,
                featuredImage,
                alpineIqApiKey,
                alpineIqUID,
                about,
                todaysSpecial,
                email,
                jarsRewards,
                referAFriend,
                pageTitle,
                schema,
                canonical
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<RetailerServiceIHeartJane | Error> {
        try {
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<any | Error> {
        try {
            return await this.find({
                where: {
                    ...query,
                    isDeleted: false
                },
                order: {
                    createdAt: "DESC"
                }
            });
        } catch (e) {
            return e;
        }
    }

    async topFiveRetailerEntity(): Promise<any | Error> {
        try {
            return await this.find({
                where: {
                    isDeleted: false
                },
                order: {
                    accessCount: "DESC"
                },
                take: 5
            });
        } catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(RetailerServiceIHeartJane)
                .set({ isDeleted: true })
                .where("id = :id", { id: id })
                .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        } catch (e) {
            return e;
        }
    }

    async createEntities(dtos: any): Promise<any | Error> {
        await getConnection()
            .createQueryBuilder()
            .insert()
            .into(RetailerServiceIHeartJane)
            .values(dtos)
            .execute();
    }
}