import { HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectRepository } from "@nestjs/typeorm";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { WeeklyAdTagsListRepository } from "./weekly-ad-tags-list.repository";
import { CreateWeeklyAdTagsListDto } from "./dto/create-weekly-ad-tags-list.dto";
import { UpdateWeeklyAdTagsListDto } from "./dto/update-weekly-ad-tags-list.dto";
import { WeeklyAdTagsList } from "./entities/weekly-ad-tags-list.entity";
import { WeeklyAdRepository } from "../weekly-ad/weekly-ad.repository";

@Injectable()
export class WeeklyAdTagsListService {
  constructor(
    @InjectRepository(WeeklyAdTagsListRepository)
    private readonly repository: WeeklyAdTagsListRepository,
    @InjectRepository(WeeklyAdRepository)
    private readonly weeklyAdRepository: WeeklyAdRepository
  ) {
  }

  async create(dto: CreateWeeklyAdTagsListDto): Promise<WeeklyAdTagsList | Error> {
    const data = await this.repository.createEntity(dto);
    if (!data) {
      throw new HttpException(
        Constants.CREATE_FAILED,
        HttpStatus.BAD_REQUEST
      );
    }
    return ResponseUtils.successResponseHandler(201, "Data created successfully", "data", data);
  }

  async update(id: string, dto: UpdateWeeklyAdTagsListDto): Promise<WeeklyAdTagsList | Error> {
    const res: any = await this.repository.findOneEntity(id);
    if (!res) {
      throw new HttpException(
        Constants.NOT_FOUND,
        HttpStatus.NOT_FOUND
      );
    }
    const data = await this.repository.updateEntity(id, dto);
    if (!data) {
      throw new HttpException(
        Constants.UPDATE_FAILED,
        HttpStatus.BAD_REQUEST
      );
    }
    return ResponseUtils.successResponseHandler(200, "Data updated successfully", "data", data);
  }

  async findAll(): Promise<WeeklyAdTagsList[] | Error> {
    const data = await this.repository.findByFilterQuery({});
    if (!data) {
      throw new HttpException(
        Constants.NOT_FOUND,
        HttpStatus.NOT_FOUND
      );
    }
    return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
  }

  async filterWeeklyAdByTag(tagId: string, stateCode: string): Promise<WeeklyAdTagsList[] | Error> {
    const resData: any = await this.repository.findByFilterQuery({ tagId: tagId });
    if (!resData) {
      throw new HttpException(
        Constants.NOT_FOUND,
        HttpStatus.NOT_FOUND
      );
    }

    let data: any = [];
    if (resData?.length > 0) {
      for (const da of resData) {
        const response = await this.weeklyAdRepository.findByFilterQuery({ id: da.weeklyAdId, stateCode: stateCode });
        if (response[0]) {
          data.push(response[0]);
        }
      }
    }

    if (!tagId) {
      data = await this.weeklyAdRepository.findByFilterQuery({ stateCode: stateCode });
    }

    return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
  }

  async findOne(id: string): Promise<WeeklyAdTagsList[] | Error> {
    const data = await this.repository.findByFilterQuery({ id: id });
    if (!data) {
      throw new HttpException(
        Constants.NOT_FOUND,
        HttpStatus.NOT_FOUND
      );
    }
    return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
  }

  async remove(id: string): Promise<boolean | Error> {
    const data = await this.repository.deleteEntity(id);
    if (!data) {
      throw new HttpException(
        Constants.NOT_FOUND,
        HttpStatus.NOT_FOUND
      );
    }
    return ResponseUtils.buildDeletedData(data, 200, "Data deleted successfully");
  }
}
