import { Body, Controller, Delete, Get, Param, Patch, Post, UseGuards } from "@nestjs/common";
import { Constants } from "src/utils/constants";
import { WeeklyAdTagsService } from "./weekly-ad-tags.service";
import { CreateWeeklyAdTagsDto } from "./dto/create-weekly-ad-tags.dto";
import { UpdateWeeklyAdTagsDto } from "./dto/update-weekly-ad-tags.dto";
import { AdminAuthGuard } from "src/core/guards/admin-auth.guard";

@Controller({ path: "weekly-ad-tags", version: Constants.API_VERSION_1 })

export class WeeklyAdTagsController {
    constructor(private readonly service: WeeklyAdTagsService) {
    }

    @Post()
    @UseGuards(AdminAuthGuard)
    create(@Body() dto: CreateWeeklyAdTagsDto) {
        return this.service.create(dto);
    }

    @Get()
    // @UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }

    @Get(":id")
    @UseGuards(AdminAuthGuard)
    findOne(@Param("id") id: string) {
        return this.service.findOne(id);
    }

    @Patch("/:id")
    @UseGuards(AdminAuthGuard)
    update(@Param("id") id: string, @Body() dto: UpdateWeeklyAdTagsDto) {
        return this.service.update(id, dto);
    }

    @Delete(":id")
    @UseGuards(AdminAuthGuard)
    async remove(@Param("id") id: string) {
        return await this.service.remove(id);
    }
}
