import {
    Body,
    Controller,
    Delete,
    Get,
    Param,
    Patch,
    Post,
    Query,
    UploadedFiles,
    UseGuards,
    UseInterceptors
} from "@nestjs/common";
import { AdminAuthGuard } from "src/core/guards/admin-auth.guard";
import { Constants } from "src/utils/constants";
import { FileFieldsInterceptor } from "@nestjs/platform-express";
import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { WeeklyAdService } from "./weekly-ad.service";
import { UpdateWeeklyAdDto } from "./dto/update-weekly-ad.dto";
import { BaseWeeklyAdDto } from "./dto/base-weekly-ad.dto";

@Controller({ path: "weekly-ad", version: Constants.API_VERSION_1 })

export class WeeklyAdController {
    constructor(private readonly service: WeeklyAdService) {
    }

    @Post()
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor(
      [
          { name: "backgroundImage", maxCount: 1 }
      ]
    ))
    create(@Body() dto: BaseWeeklyAdDto,
           @UploadedFiles() files: {
               backgroundImage: UploadedMulterFileI
           }) {
        return this.service.create(dto, files);
    }

    @Get()
    // @UseGuards(AdminAuthGuard)
    findAll(@Query("stateCode") stateCode: string) {
        return this.service.findAll(stateCode);
    }

    @Get(":id")
    @UseGuards(AdminAuthGuard)
    findOne(@Param("id") id: string) {
        return this.service.findOne(id);
    }

    @Patch("/:id")
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor(
      [
          { name: "backgroundImage", maxCount: 1 }
      ]
    ))
    update(
      @Param("id") id: string,
      @Body() dto: UpdateWeeklyAdDto,
      @UploadedFiles() files: {
          backgroundImage: UploadedMulterFileI
      }) {
        return this.service.update(id, dto, files);
    }

    @Delete(":id")
    @UseGuards(AdminAuthGuard)
    async remove(@Param("id") id: string) {
        return await this.service.remove(id);
    }
}
